/*
******************************************************************************

   Demo of the EDEMO extension.

   Authors:	1999 Marcus Sundberg	[marcus@ggi-project.org]
  
   This code is placed in the public domain and may be used freely for any
   purpose.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <stdio.h>
#include <stdlib.h>

#include <ggi/ggi.h>
#include <ggi/edemo.h>


static int do_demo(ggi_visual_t vis)
{
	/* Try the API functions */
	edemoFunction1(vis, 42);
	edemoFunction2(vis, 17, 4711);

	return 0;
}	/* do_demo */



int main(void)
{
	int rc;
	ggi_visual_t vis;

	/* Initialize LibGGI */
	if (ggiInit() != 0) {
		fprintf(stderr, "Unable to initialize LibGGI\n");
		exit(1);
	}
	
	/* Initialize EDEMO extension */
	if (edemoInit() != 0) {
		ggiPanic("Unable to initialize LibEDEMO extension\n");
	}

	/* Open the default visual */
	if ((vis = ggiOpen(NULL)) == NULL) {
		ggiPanic("Unable to open default visual\n");
	}
	
	/* Turn on asynchronous mode (which should always be used) */
	ggiSetFlags(vis, GGIFLAG_ASYNC);
	
	/* Set the default mode */
	if (ggiSetSimpleMode(vis, GGI_AUTO, GGI_AUTO, GGI_AUTO, GT_AUTO) < 0) {
		ggiPanic("Unable to set default mode\n");
	}
	
	/* Attach the EDEMO extension to the visual */
	if (edemoAttach(vis) < 0) {
		ggiPanic("Unable to attach EDEMO extension to visual\n");
	}

	/* Do demo */
	rc = do_demo(vis);
	
	/* Detach extension from visual */
	edemoDetach(vis);

	/* Close visual */
	ggiClose(vis);

	/* Deinitialize EDEMO extension */
	edemoExit();

	/* Deinitialize LibGGI */
	ggiExit();

	return 0;
}	/* main */
